N.C. Appellate Courts
Keywords: supreme, court

SUPREME COURT OPINIONS - 2014
Last Modified: April 16 2014 05:25:38 PM

11 April 2014 Zip File of Published Opinions Mandate: 1 May 2014 Case Title / Description
Beroth Oil Co. v. N.C. Dep't of Transp., (390PA11-2) Interlocutory appeal; whether the trial court erred in denying plaintiffs' motion for class certification of their inverse condemnation claim
State v. Stokes, (94PA13-2) Whether, after holding that the State presented insufficient evidence to convict defendant of second-degree kidnapping, the COA correctly declined to consider whether defendant committed the lesser included offense of attempted second-degree kidnapping
State v. Barnes, (461A13) Whether a person can be convicted of possessing marijuana in a local confinement facility under N.C.G.S. § 90-95(e)(9) after having been involuntarily brought into the facility following an arrest
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED 90 OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
7 March 2014 Zip File of Published Opinions Mandate: 27 March 2014 Case Title / Description
State v. Joe, (333PA11-2) On remand; whether trial court erred in granting defendant's pretrial motions to suppress and to dismiss the charge of resisting a public officer
State v. Jones, (527A12) Whether indictments charging Jones with obtaining property by false pretenses and charging his codefendant with trafficking in stolen identities were properly dismissed by the trial court; whether the State offered sufficient proof of identity theft to support Jones's conviction for that offense
Gregory v. Pearson, (116PA13) Workers' Compensation; whether plaintiff's decedent, an employee of a temporary agency that assigned him to work at a County facility, was also a County employee under the special employment doctrine
In re Suttles Surveying, P.A., (252PA13) Whether the N.C. Board of Examiners for Engineers and Surveyors exceeded its statutory authority or violated the due process rights of a licensee and his company by disciplining them for violating the Board's professional conduct rules
In re E.H., (302PA13) Whether DSS can voluntarily dismiss a juvenile petition alleging abuse and neglect before an adjudication hearing is held; interpretation of N.C. R. Civ. P. 41(a) in conjunction with N.C.G.S. § 7B-201(a)
State v. Howard, (320A13) Firearms possession charge; admissibility of evidence under Rule 404(b) about defendant's previous arrest; whether defendant properly preserved the issue he argued on appeal
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
24 January 2014 Zip File of Published Opinions Mandate: 13 February 2014 Case Title / Description
State v. Whittington, (291PA12) Whether a defendant's Confrontation Clause rights were violated when a witness who did not conduct tests identifying a substance as opium testified to the results of an analysis done by a nontestifying chemist; application of the waiver provisions of N.C.G.S. § 90-95(g)
Glens of Ironduff Prop. Owners Ass'n, Inc. v. Daly, (21PA13) Whether the six year statute of repose applicable to a homeowners' association's claim for negligent road construction is tolled by N.C.G.S. § 47F-3-111(c) until the period of declarant control terminates
Rutherford Plantation, LLC v. Challenge Golf Grp. of the Carolinas, LLC, (79A13) Action to recover balance due on a purchase money promissory note and secured by a purchase money deed of trust; trial court's grant of partial summary judgment for amount due on note; whether the trial court made an error of law for which defendant is entitled to amendment of the partial summary judgment order
In re Blue Ridge Hous. of Bakersville LLC, (173PA13) Exemption of low-income housing project from ad valorem taxation under N.C.G.S. §§ 105-278.6(a)(8) and -277.16
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.